<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class ConfirmaEnderecoFactory {
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function searchCountry($params){
        
        $queryConfirmCountry = "SELECT NMPAIS
                        FROM PAIS
                       WHERE (UPPER(NMPAIS) = UPPER(:NMPAIS) OR 
                         UPPER(NMPAIS) = UPPER(:PAISSEMACENTO)) ";   
                         
        try {
            $std = $this->connection->prepare($queryConfirmCountry);
            $std->execute($params);
            $returnedCountry = $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
        
        if(empty($returnedCountry)){
            return array();
        }else{
            return $returnedCountry[0]['NMPAIS'];
        }
    }
    
    public function searchState($params){
        
        $queryConfirmState = "SELECT NMESTADO
                        FROM ESTADO
                       WHERE (UPPER(NMESTADO) = UPPER(:NMESTADO) OR 
                         UPPER(NMESTADO) = UPPER(:NMESTADOSEMACENTO))
                        AND CDPAIS = :CDPAIS";   
                         
        try {
            $std = $this->connection->prepare($queryConfirmState);
            $std->execute($params);
            $returnedState = $std->fetchAll();
            
        } catch (\Exception $e){
            throw $e;
        }
        
        if(empty($returnedState)){
            return array();
        } else {
            return $returnedState[0]['NMESTADO'];
        }
    }
    
    public function searchCity($params){
        $queryConfirmCity = "SELECT NMMUNICIPIO
                        FROM MUNICIPIO
                       WHERE (UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO) OR 
                         UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIOSEMACENDO)) 
                        AND CDPAIS   = :CDPAIS 
                        AND SGESTADO = :SGESTADO";   
        try {
            $std = $this->connection->prepare($queryConfirmCity);
            $std->execute($params);
            $returnedCity = $std->fetchAll();
            
        } catch (\Exception $e){
            throw $e;
        }
        
        if(empty($returnedCity)){
            return array();
        } else {
            return $returnedCity[0]['NMMUNICIPIO'];
        }
    }
    
    public function searchNeigh($params){
        $queryConfirmNeigh = "SELECT NMBAIRRO,
                        CDBAIRRO
                        FROM BAIRRO
                       WHERE (UPPER(NMBAIRRO) = UPPER(:NMBAIRRO) OR 
                         UPPER(NMBAIRRO) = UPPER(:NMBAIRROSEMACENTO)) 
                        AND CDPAIS      = :CDPAIS 
                        AND SGESTADO    = :SGESTADO 
                        AND CDMUNICIPIO = :CDMUNICIPIO";
                         
        try {
            $std = $this->connection->prepare($queryConfirmNeigh);
            $std->execute($params);;
            $returnedNeigh = $std->fetchAll();
            
        } catch (\Exception $e){
            throw $e;
        }
        
        if(empty($returnedNeigh)){
            return array();
        } else {
            return $returnedNeigh[0];
        }
    }
    
    public function inserirBairro(array $params) {
        $sql = "INSERT INTO BAIRRO (
                    CDPAIS,         SGESTADO,       CDMUNICIPIO,
                    CDBAIRRO,       NMBAIRRO,       IDATIVO,
                    NRORG,          DTINCLUSAO,     CDOPERINCLUSAO,
                    NRORGINCLUSAO
                )
                VALUES (
                    :CDPAIS,        :SGESTADO,      :CDMUNICIPIO,
                    :CDBAIRRO,      :NMBAIRRO,      :IDATIVO,
                    :NRORG,         SYSDATE,        :CDOPERINCLUSAO,
                    :NRORGINCLUSAO
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
  
}